function [ roots_p ] = poly_plot(p,xmin,xmax,xstep,yoffset)
% poly_plot(p,xmin,xmax,xstep,yoffset)
%   Function to take in a arbitrary polynomial, p and plot it over a gven
%   range and plot all its REAL roots.
%
%   INPUTS: p - vector of polynomial coefficients. See man poly for
%   details
%           xmin - minimum value of x range
%           xmax - maximum value of x range
%           xstep - increment step size for x
%           yoffset - offset from y values for plot prettiness.
%
%   Output: roots_p - roots of the polynomial



% Create some x values to evaluate y

x=xmin:xstep:xmax;  % Make x


y = polyval(p,x); %evaluate polynomial

plot(x,y); % plot it


%%%  Plot X and Y axes and label

%intialise caption

caption = char(poly2sym(p));

caption = strcat('f(x) = ', caption);


% Set Title of Graph

title(caption);

hold on
plot([xmin xmax],[0 0],'-k'); % X Axis
plot([0 0],[min(y)-yoffset max(y)+yoffset],'-k'); % Y Axis


axis tight % force concise display of plot


roots_p = roots(p);  % Solve the Equation  


% Plot Roots

% In general roots of polynomial may be comlex.
hold on;

[n m] = size(roots_p); % n = how many roots

for i = 1:n

    if isreal(roots_p(i)) % NOTE in this case no REAL roots

        plot(roots_p(i),0,'o','LineWidth',2,...
                'MarkerEdgeColor','k',...
                'MarkerFaceColor','r',...
                'MarkerSize',10);
    end;



end;

hold off;

shg; % Show Figure




